==> webkit-1.6.3.tar.xz: webkit-1.6.3/Source/WebKit2/Shared/WebOpenPanelParameters.h <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebOpenPanelParameters_h
#define WebOpenPanelParameters_h

#include "APIObject.h"
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>

namespace CoreIPC {
    class ArgumentDecoder;
    class ArgumentEncoder;
}

namespace WebKit {

class WebOpenPanelParameters : public APIObject {
public:
    static const Type APIType = TypeOpenPanelParameters;

    struct Data {
        void encode(CoreIPC::ArgumentEncoder*) const;
        static bool decode(CoreIPC::ArgumentDecoder*, Data&);

        bool allowMultipleFiles;
        bool allowsDirectoryUpload;
        String acceptTypes;
        Vector<String> filenames;
    };

    static PassRefPtr<WebOpenPanelParameters> create(const Data&);
    ~WebOpenPanelParameters();

    bool allowMultipleFiles() const { return m_data.allowMultipleFiles; } 
    Vector<String> selectedFileNames() const { return m_data.filenames; }

private:
    explicit WebOpenPanelParameters(const Data&);

    virtual Type type() const { return APIType; }

    Data m_data;
};

} // namespace WebKit

#endif // WebOpenPanelParameters_h

==> webkit-1.8.0.tar.xz: webkit-1.8.0/Source/WebKit2/Shared/WebOpenPanelParameters.h <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebOpenPanelParameters_h
#define WebOpenPanelParameters_h

#include "APIObject.h"
#include <WebCore/FileChooser.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>

namespace WebKit {

class ImmutableArray;

class WebOpenPanelParameters : public APIObject {
public:
    static const Type APIType = TypeOpenPanelParameters;

    static PassRefPtr<WebOpenPanelParameters> create(const WebCore::FileChooserSettings&);
    ~WebOpenPanelParameters();

    bool allowMultipleFiles() const { return m_settings.allowsMultipleFiles; } 
    PassRefPtr<ImmutableArray> acceptMIMETypes() const;
    Vector<String> selectedFileNames() const { return m_settings.selectedFiles; }

private:
    explicit WebOpenPanelParameters(const WebCore::FileChooserSettings&);

    virtual Type type() const { return APIType; }

    WebCore::FileChooserSettings m_settings;
};

} // namespace WebKit

#endif // WebOpenPanelParameters_h
